Learn R Programming

b3archives (version 1.0.0)

b3_indexreport_download: Get Index Report BVBG.087.01

Description

Downloads archive Index Report BVBG.087.01 from B3's website

Usage

b3_indexreport_download(date, last = TRUE, directory = tempdir())

Arguments

date

"yyyy-mm-dd" in class Date format

last

logical setting if we keep all files or choose the last one

directory

a string for the directory where the files will be saved

Value

a file

Examples

Run this code
# NOT RUN {
b3_indexreport_download(as.Date("2020-01-31"))
# }

Run the code above in your browser using DataLab