powered by
Downloads archive Index Report BVBG.087.01 from B3's website
b3_indexreport_download(date, last = TRUE, directory = tempdir())
"yyyy-mm-dd" in class Date format
logical setting if we keep all files or choose the last one
a string for the directory where the files will be saved
a file
# NOT RUN { b3_indexreport_download(as.Date("2020-01-31")) # }
Run the code above in your browser using DataLab